@@ -22,8 +22,10 @@ function log_message($message, $level = 'INFO') {
     $timestamp = date('Y-m-d H:i:s');
     $log_entry = "[{$timestamp}] [{$level}] {$message}\n";
     
-    // Log to console if running interactively
-    if (posix_isatty(STDOUT)) {
+    // Log to console if running interactively (with fallback for missing posix extension)
+    $is_interactive = (function_exists('posix_isatty') && posix_isatty(STDOUT)) || 
+                     (php_sapi_name() === 'cli' && !getenv('CRON_JOB'));
+    if ($is_interactive) {
         echo $log_entry;
     }
     
